import Vue from "vue";

Vue.mixin({
  beforeCreate() {
    if (document.getElementById("app-placeholder"))
      document.getElementById("app-placeholder").remove();
  },
  mounted() {
    // console.log("mixin hook called");
    [...document.getElementsByTagName("a")].forEach(e => {
      e.addEventListener("click", function(event) {
        event.preventDefault();
      });
    });
  },
  methods: {
    async serverLog(level, logText) {
      try {
        await this.$http.post(
          "/api/ecs_core/log/studentClient/" + level,
          logText,
          {
            headers: {
              "Content-Type": "text/plain",
            },
          }
        );
      } catch (error) {
        console.log(error);
      }
    },
    async checkExamInProgress() {
      try {
        // 断点续考
        const examingRes = (await this.$http.get(
          "/api/ecs_oe_student/examControl/checkExamInProgress"
        )).data;

        if (examingRes.isExceed) {
          // 超出断点续考次数的逻辑，仅此block
          this.$Message.info({
            content: `超出最大断点续考次数(${examingRes.maxInterruptNum})，正在自动交卷...`,
            duration: 15,
            closable: true,
          });
          this.$Spin.show({
            render: () => {
              return (
                <div style="font-size: 24px">
                  超出最大断点续考次数({examingRes.maxInterruptNum}
                  )，正在自动交卷...
                </div>
              );
            },
          });
          const res = await this.$http.get(
            "/api/ecs_oe_student/examControl/endExam"
          );
          let resAfter;
          if (res.status === 200) {
            for (let i = 0; i < 10; i++) {
              await new Promise(resolve => setTimeout(() => resolve(), 3000));
              resAfter = await this.$http.get(
                "/api/ecs_oe_student/examControl/processAfterEndExam?examRecordDataId=" +
                  examingRes.examRecordDataId
              );
              console.log(resAfter);
              if (resAfter.data.code === "S-101000") {
                continue;
              } else if (resAfter.data.code === "000000") {
                break;
              }
            }
          }
          if (res.status === 200 && resAfter.data.code === "000000") {
            this.$router.replace({
              path: `/online-exam/exam/${examingRes.examId}/examRecordData/${examingRes.examRecordDataId}/end`,
            });
            this.$Spin.hide();
          } else {
            this.$Message.error({
              content: "交卷失败",
              duration: 15,
              closable: true,
            });
          }
          throw "交卷失败";
        }

        if (examingRes) {
          this.$Spin.show({
            render: () => {
              return <div style="font-size: 24px">正在进入断点续考...</div>;
            },
          });
          this.$router.push(
            `/online-exam/exam/${examingRes.examId}/examRecordData/${examingRes.examRecordDataId}/order/1` +
              (examingRes.faceVerifyMinute
                ? `?faceVerifyMinute=${examingRes.faceVerifyMinute}`
                : "")
          );
          setTimeout(() => this.$Spin.hide(), 1000);
          return true;
        }
      } catch (error) {
        this.$Message.error({
          content: "获取断点续考信息异常",
          duration: 15,
          closable: true,
        });
        throw error;
      }
    },
    logout(cause = "") {
      localStorage.removeItem("phoneVerified");
      window._hmt.push(["_trackEvent", "退出", cause]);
      const redirectUrl = sessionStorage.getItem("redirectUrl");
      if (redirectUrl) {
        this.$Modal.error({
          title: "确认退出",
          content: "",
          onOk: () => {
            window.location = redirectUrl;
          },
        });
      } else {
        this.$router.push("/login/" + localStorage.getItem("domain") + cause);
      }
    },
  },
});
